@@ -228,7 +228,7 @@ class WebsocketClient:
     def _add_callback(
         callback_list: list, callback: Callable[..., Any]
     ) -> Callable[..., None]:
-        """Add a callback callback to a particular list."""
+        """Add a callback to a particular list."""
         callback_list.append(callback)
 
         def remove() -> None:
@@ -284,7 +284,7 @@ class WebsocketClient:
                 schedule_callback(callback, event)
 
     def add_connect_callback(self, callback: Callable[..., Any]) -> Callable[..., None]:
-        """Add a callback callback to be called after connecting.
+        """Add a callback to be called after connecting.
 
         :param callback: The method to call after connecting
         :type callback: ``Callable[..., None]``
@@ -294,7 +294,7 @@ class WebsocketClient:
     def add_disconnect_callback(
         self, callback: Callable[..., Any]
     ) -> Callable[..., None]:
-        """Add a callback callback to be called after disconnecting.
+        """Add a callback to be called after disconnecting.
 
         :param callback: The method to call after disconnecting
         :type callback: ``Callable[..., None]``
@@ -302,7 +302,7 @@ class WebsocketClient:
         return self._add_callback(self._disconnect_callbacks, callback)
 
     def add_event_callback(self, callback: Callable[..., Any]) -> Callable[..., None]:
-        """Add a callback callback to be called upon receiving an event.
+        """Add a callback to be called upon receiving an event.
 
         Note that callbacks should expect to receive a WebsocketEvent object as a
         parameter.
@@ -314,6 +314,9 @@ class WebsocketClient:
 
     async def async_connect(self) -> None:
         """Connect to the websocket server."""
+        if self.connected:
+            return
+
         try:
             self._client = await self._api.session.ws_connect(
                 WEBSOCKET_SERVER_URL, heartbeat=55
@@ -323,22 +326,22 @@ class WebsocketClient:
 
         LOGGER.info("Connected to websocket server")
 
+        self._watchdog.trigger()
+
         for callback in self._connect_callbacks:
             schedule_callback(callback)
 
-        self._watchdog.trigger()
-
     async def async_disconnect(self) -> None:
         """Disconnect from the websocket server."""
+        if not self.connected:
+            return
+
         assert self._client
 
         await self._client.close()
 
         LOGGER.info("Disconnected from websocket server")
 
-        for callback in self._disconnect_callbacks:
-            schedule_callback(callback)
-
     async def async_listen(self) -> None:
         """Start listening to the websocket server."""
         assert self._client
@@ -374,6 +377,8 @@ class WebsocketClient:
         finally:
             LOGGER.debug("Listen completed; cleaning up")
 
+            self._watchdog.cancel()
+
             for callback in self._disconnect_callbacks:
                 schedule_callback(callback)
 
